@@ -10,18 +10,6 @@ class oauthnesia():
     user_key = ""
     user_secret = ""
 
-    default_post = {
-        'oauth_consumer_key': None,
-        'oauth_nonce': None,
-        'oauth_signature_method': 'HMAC-SHA1',
-        'oauth_timestamp': None,
-        'oauth_version': '1.0',
-        'safe_encode': 1
-    }
-
-    post = {}
-    get = {}
-
     def __init__(self, base_url=None, cons_key=None, cons_sec=None, user_key=None, user_sec=None):
         if base_url:
             self.api_base_url = base_url
